<!-- Remember, this produces the front page on github, dockerhub, and pypi. -->

# Robotic Manipulation

*Perception, Planning, and Control*

This is the companion software for the textbook available at:
https://manipulation.mit.edu/

Online code documentation can be found
[here](https://manipulation.mit.edu/python/index.html).

For contributions, please see [developer instructions](Developers.md).

To cite this software (or the corresponding textbook), please use:

Russ Tedrake. _Robotic Manipulation: Perception, Planning, and Control (Course
Notes for MIT 6.421)._ Downloaded on [date] from <https://manipulation.mit.edu/>.
